pub struct Argument { /* private fields */ }Expand description
A opaque handle to a transaction input or command result.
Arguments are produced by builder methods like TransactionBuilder::pure,
TransactionBuilder::object, and TransactionBuilder::move_call, and consumed by
command methods like TransactionBuilder::transfer_objects.
For commands that return multiple values (e.g., TransactionBuilder::split_coins),
use to_nested to access individual results.
Implementations
Sourceimpl Argument
impl Argument
Sourcepub fn to_nested(self, count: usize) -> Vec<Self>
pub fn to_nested(self, count: usize) -> Vec<Self>
Split this argument into count nested result arguments.
This is used when a command (like a Move call) returns multiple values. Each element in the returned vector refers to the corresponding result index.
TransactionBuilder::split_coins calls this automatically, but you can use it
directly for Move calls that return multiple values:
use sui_sdk_types::Address;
use sui_sdk_types::Identifier;
use sui_transaction_builder::Function;
use sui_transaction_builder::TransactionBuilder;
let mut tx = TransactionBuilder::new();
let result = tx.move_call(
Function::new(
Address::TWO,
Identifier::from_static("my_module"),
Identifier::from_static("multi_return"),
),
vec![],
);
let nested = result.to_nested(3);
assert_eq!(nested.len(), 3);Trait Implementations