SimulationFailure

Struct SimulationFailure 

pub struct SimulationFailure { /* private fields */ }
Available on crate feature intents only.
Rich error information from a failed transaction simulation.

Implementations

Source

impl SimulationFailure

pub fn execution_error(&self) -> &ExecutionError

Returns the underlying execution error.

pub fn description(&self) -> Option<&str>

Returns the human-readable error description, if available.

pub fn command(&self) -> Option<u64>

Returns the command index that failed, if available.

pub fn kind(&self) -> Option<ExecutionErrorKind>

Returns the error kind, if available.

pub fn move_abort(&self) -> Option<&MoveAbort>

Returns the Move abort details, if this was a MoveAbort error.

pub fn clever_error(&self) -> Option<&CleverError>

Returns the clever error details, if available.

Clever errors provide structured information about Move abort codes, including the error constant name, type, and value.