pub struct ObjectInput { /* private fields */ }Expand description
Description of an on-chain object to use as a transaction input.
Use one of the constructors (new, owned,
shared, immutable, receiving)
and then optionally refine with builder methods like with_version,
with_digest, and with_mutable.
use sui_sdk_types::Address;
use sui_sdk_types::Digest;
use sui_transaction_builder::ObjectInput;
// Fully-specified owned object
let obj = ObjectInput::owned(Address::ZERO, 1, Digest::ZERO);
// Minimal object — additional fields can be filled in by the builder
let obj = ObjectInput::new(Address::ZERO);
// Shared object
let obj = ObjectInput::shared(Address::ZERO, 1, true);Implementations
Sourceimpl ObjectInput
impl ObjectInput
Sourcepub fn new(object_id: Address) -> Self
pub fn new(object_id: Address) -> Self
Create a minimal object input with only an object ID.
Additional metadata (kind, version, digest, mutability) can be later resolved when a transaction is built.
Sourcepub fn owned(object_id: Address, version: u64, digest: Digest) -> Self
pub fn owned(object_id: Address, version: u64, digest: Digest) -> Self
Return an owned kind of object with all required fields.
Sourcepub fn immutable(object_id: Address, version: u64, digest: Digest) -> Self
pub fn immutable(object_id: Address, version: u64, digest: Digest) -> Self
Return an immutable kind of object with all required fields.
Sourcepub fn receiving(object_id: Address, version: u64, digest: Digest) -> Self
pub fn receiving(object_id: Address, version: u64, digest: Digest) -> Self
Return a receiving kind of object with all required fields.
Return a shared object.
mutablecontrols whether a command can accept the object by value or mutable reference.versionis the first version the object was shared at.
Sourcepub fn as_immutable(self) -> Self
pub fn as_immutable(self) -> Self
Set the object kind to immutable.
Sourcepub fn as_receiving(self) -> Self
pub fn as_receiving(self) -> Self
Set the object kind to receiving.
Set the object kind to shared.
Sourcepub fn with_version(self, version: u64) -> Self
pub fn with_version(self, version: u64) -> Self
Set the specified version.
Sourcepub fn with_digest(self, digest: Digest) -> Self
pub fn with_digest(self, digest: Digest) -> Self
Set the specified digest.
Sourcepub fn with_mutable(self, mutable: bool) -> Self
pub fn with_mutable(self, mutable: bool) -> Self
Set whether this object is accessed mutably.
This is primarily relevant for shared objects to indicate whether the command will take the object by value or mutable reference.