pub struct SimulationFailure { /* private fields */ }Available on crate feature
intents only.Expand description
Rich error information from a failed transaction simulation.
Implementations
Sourceimpl SimulationFailure
impl SimulationFailure
Sourcepub fn execution_error(&self) -> &ExecutionError
pub fn execution_error(&self) -> &ExecutionError
Returns the underlying execution error.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Returns the human-readable error description, if available.
Sourcepub fn move_abort(&self) -> Option<&MoveAbort>
pub fn move_abort(&self) -> Option<&MoveAbort>
Returns the Move abort details, if this was a MoveAbort error.
Sourcepub fn clever_error(&self) -> Option<&CleverError>
pub fn clever_error(&self) -> Option<&CleverError>
Returns the clever error details, if available.
Clever errors provide structured information about Move abort codes, including the error constant name, type, and value.